@@ -1,15 +1,14 @@
 from fdrtd.plugins.simon.microservice import MicroserviceSimon
 
 
-def get_microservices():
+def list_root_objects():
     return [
         {
             "identifiers": {
                 "namespace": "fdrtd",
                 "protocol": "Simon",
-                "version": "0.1.1"
+                "version": "0.5.2"
             },
-            "class": MicroserviceSimon,
-            "public": ["compute", "get_task", "create_task", "join_task", "peer_to_peer"]
+            "object": MicroserviceSimon()
         }
     ]
