@@ -6,8 +6,8 @@ from fdrtd.plugins.simon.microprotocols.microprotocol import Microprotocol
 
 class MicroprotocolStatisticsRegressionOLSVertical(Microprotocol):
 
-    def __init__(self, bus, properties, myself):
-        super().__init__(bus, properties, myself)
+    def __init__(self, microservice, properties, myself):
+        super().__init__(microservice, properties, myself)
 
         self.register_cache('input', Cache())
         self.register_cache('final', Cache())
